/*=====================================================================
File: AddInEntryPoint.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) N/A
=====================================================================*/
using System;
using System.Windows.Forms;
using OpenCellar.Application;
using OpenCellar.Import.Framework;

namespace OpenCellar.AddIn.ImportWizard
{
	/// <summary>
	/// AddInEntryPoint.
	/// </summary>
	public class AddInEntryPoint : IAddIn
	{
		const int		CM_EXECUTE_WIZARD	= 200;
		const string	CM_EXECUTE_NAME		= "Excuter l'assistant...";
		const string	CM_MAIN_MENU		= "Assistant importation de donnes externes";

		private IApplication m_application = null;

		/// <summary>
		/// Initialise une instance de classe MergeEntryPoint.
		/// </summary>
		public AddInEntryPoint()
		{
			ExternalConnector.Instance.GetType(); // .Register(new ExternalConnectorInfo(typeof(TestWindowsFactory)));
		}

		/// <summary>
		/// Nettoyage des reessources.
		/// </summary>
		public void OnUnInitialize(){}

		/// <summary>
		/// Appele par l'application lors d'un clic sur menu.
		/// </summary>
		/// <param name="command"></param>
		public void OnCommand(int command)
		{
			if(command != CM_EXECUTE_WIZARD)
			{
				return;
			}

			if(m_application.ActiveCellar == null)
			{
				if(m_application.ShowMessage("Open Cellar",
					"L'assistant importation de donnes externes requiert qu'une cave soit ouverte.\n\nCliquez sur Oui pour slectionner une cave existante.\nCliquez sur Non pour quitter l'assistant et revenir sous Open Cellar.",
					MessageBoxIcon.Question,
					MessageBoxButtons.YesNo) == DialogResult.Yes)
				{
					m_application.Macros.OpenCellar.Execute();
				}
			}

			if(m_application.ActiveCellar == null)
			{
				return;
			}

			ProcessWizard();
		}

		/// <summary>
		/// Affiche la fenetre
		/// </summary>
		private void ProcessWizard()
		{
			using(Wizard bw = new Wizard(m_application.ActiveCellar))
			{
				bw.ShowDialog();
			}
		}		

		/// <summary>
		/// Est appele par l'application
		/// </summary>
		/// <param name="application"></param>
		public void OnInitialize(IApplication application)
		{
			m_application = application;
			HackMainMenu();
		}

		private void HackMainMenu()
		{
			Form main = m_application.MainCommandBars.GetBar(0).GetItem(0).GetControl().FindForm();
			if(main == null)
			{
				return;
			}
			if(main.Menu == null)
			{
				return;
			}

			MenuItem importMenuItem = new MenuItem("Importer des donnes externes...");
			importMenuItem.Click+=new EventHandler(OnImportMenuClick);
			main.Menu.MenuItems[0].MenuItems.Add(2, importMenuItem);
		}

		/// <summary>
		/// Obtient une reference vers l'application.
		/// </summary>
		public IApplication Application
		{
			get
			{
				return(m_application);
			}
		}

		/// <summary>
		/// Eneregistrement des menus dans l'application
		/// </summary>
		/// <param name="addInMenus"></param>
		public void OnRegisterMenus(AddInMenus addInMenus)
		{
			addInMenus.SetMainMenuCaption(CM_MAIN_MENU);
			addInMenus.Register(CM_EXECUTE_WIZARD, CM_EXECUTE_NAME);
		}

		private void OnImportMenuClick(object sender, EventArgs e)
		{
			OnCommand(CM_EXECUTE_WIZARD);
		}
	}
}
