/*=====================================================================
File: CSVRow.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Collections.Specialized;
using System.Text;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// CSVRow
	/// </summary>
    public class CSVRow : Row
    {
        /// <summary>
        /// Initialise une instance de classe CSVRow.
        /// </summary>
        /// <param name="parent">Document parent;</param>
        /// <param name="rowIndex">Index de la ligne.</param>
        /// <param name="line">Ligne a analyser</param>
        internal protected CSVRow(CSVDocument parent,
            int rowIndex,
            string line)
            : base(parent, rowIndex)
        {
            this.__parseLine(line);
        }

        static char QuotedChar = char.Parse("\"");

        /// <summary>
        /// Analyse la chaine.
        /// </summary>
        private void __parseLine(string line)
        {
            if (line == null)
            {
                throw new ArgumentNullException("line");
            }

            char[] chars = line.ToCharArray();

            if (chars.Length == 0)
            {
                return;
            }

            char separator = ((CSVDocument)Parent).Separator;
            bool inQuote = false;
            
            StringBuilder builder = new StringBuilder();

            for (int i = 0; i < chars.Length; i++)
            {
                char c = chars[i];

                if (c == CSVRow.QuotedChar)
                {
                    if (inQuote)
                    {
                        int cpt = i + 1;
                        if (chars.Length > cpt)
                        {
                            if (chars[cpt] == separator)
                            {
                                inQuote = false;
                            }
                            else
                            {
                                builder.Append(c);
                            }
                        }
                    }
                    else
                    {
                        int cpt = i - 1;
                        if (cpt > -1)
                        {
                            if (chars[cpt] == separator)
                            {
                                inQuote = true;
                            }
                            else
                            {
                                builder.Append(c);
                            }
                        }
                        else
                        {
                            inQuote = true;
                        }
                    }
                }
                else if (c == separator)
                {
                    if (inQuote)
                    {
                        builder.Append(c);
                    }
                    else
                    {
                        base.Add(builder.ToString());
                        builder = new StringBuilder();
                    }
                }
                else
                {
                    builder.Append(c);
                }
            }

            if (chars[chars.Length - 1] != separator)
            {
                base.Add(builder.ToString());
            }
        }        
    }
}
