/*=====================================================================
File: PurchaseDateColumn.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using OpenCellar.Framework.Core;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// PurchaseDateColumn
	/// </summary>
    public class PurchaseDateColumn : Column
    {
        /// <summary>
        /// Initialise une instance de classe PurchaseDateColumn.
        /// </summary>
        public PurchaseDateColumn()
            : base(Res.COL_WINE_PURCHASE_DATE)
        { 
        }

        public override bool Process(OpenCellar.Framework.Core.Wine wine, IRow row)
        {
            // Vrifie l'indice de la colonne.
            if (!row.CheckIndice(Index))
            { 
                return (false);
            }

			if(row[Index] == string.Empty)
			{
				return(true);
			}

			bool success = false;

			// File d'attente
			if(wine.PurchaseWorkqueue.Count == 0)
			{
				PurchaseSales ps = (PurchaseSales)wine.Cellar.CreateItem(ObjectType.PurchaseSales);
				ps.Date = OCUtility.TryParseDateTime(row[Index], out success);
				wine.PurchaseWorkqueue.Set(WorkqueueItemType.Add, ps);
			}
			else
			{
				wine.PurchaseWorkqueue[0].Item.Date = OCUtility.TryParseDateTime(row[Index], out success);
			}
               
            return (success);
        }

        // <summary>
        /// Cre une copie de la colonne.
        /// </summary>
        /// <returns></returns>
        public override IColumn Clone()
        {
            return (new PurchaseDateColumn());
        }
    }
}
