/*=====================================================================
File: RackItemColumn.cs

Summary: 

Date : Octobre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Text;
using OpenCellar.Framework.Core;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// RackItemColumn.
	/// </summary>
    public sealed class RackItemColumn : Column
    {
        /// <summary>
        /// Initialise une instance de classe RackItemColumn.
        /// </summary>
        public RackItemColumn()
            : base(Res.COL_WINE_RACK_ITEM)
        { 
            
        }

        public override bool Process(OpenCellar.Framework.Core.Wine wine, IRow row)
        {
            // Vrifie l'indice de la colonne.
            if (!row.CheckIndice(Index))
            { 
                return (false);
            }

			if(row[Index] == string.Empty)
			{
				return(false);
			}


			string item = row[Index].Trim().ToLower();

			int pos = item.IndexOf("-");

			if(pos < 1)
			{
				return(false);
			}

			// Recupere la colonne de type Rack
			IColumnCollection columns = row.Parent.Columns;

			IColumn rackColumn = null;
			for (int i = 0; i < columns.Count; i++)
			{
				if(columns[i] is RackColumn)
				{
					rackColumn = columns[i];
					break;
				}
			}

			if(rackColumn == null)
			{
				return(false);
			}

			string rackName = row[rackColumn.Index].Trim().ToLower();

			if(rackName == string.Empty)
			{
				return(false);
			}

			Rack rack = null;

			ObjectCollection racks = wine.Cellar.GetCollection((ushort)ObjectType.Rack);
			for (int i = 0 ; i <  racks.Count; i++)
			{
				string name = ((Rack)racks[i]).Name.Trim().ToLower();

				if(name == rackName)
				{
					rack = (Rack)racks[i];
					break;
				}
			}

			if(rack == null)
			{
				return(false);
			}

			bool ret = false;

			byte itemColumn = OCUtility.TryParseByte(item.Substring(0, pos), out ret);
			byte itemRow = OCUtility.TryParseByte(item.Substring(pos + 1), out ret);

			// OK
			RackItem rackItem = rack.Get(itemColumn, itemRow);

			if(rackItem == null)
			{
				RackBuilder builder = new RackBuilder(rack);

				// Vrification des bornes
				if(builder.Rack.Columns < (byte)(itemColumn + 1))
				{
					builder.SetColumnsSize((byte)(itemColumn + 1));
				}
				if(builder.Rack.Rows < (byte)(itemRow + 1))
				{
					builder.SetRowsSize((byte)(itemRow + 1));
				}
				builder.Save();

				rackItem = builder.CreateRackItem(itemRow, itemColumn);
				rackItem.Save();
			}
			
			// Ajout dans la file d'attente
			wine.RackItemWorkqueue.Set(WorkqueueItemType.Add, rackItem);

            return (true);
        }

        // <summary>
        /// Cre une copie de la colonne.
        /// </summary>
        /// <returns></returns>
        public override IColumn Clone()
        {
            return (new RackItemColumn());
        }
    }
}
