/*=====================================================================
File: ExternalConnector.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Collections;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// ExternalConnector.
	/// </summary>
	public class ExternalConnector
	{
		static ExternalConnector intance = new ExternalConnector();

		/// <summary>
		/// Obtient l'instance unique de classe ExternalConnector.
		/// </summary>
		public static ExternalConnector Instance
		{
			get
			{
				return(ExternalConnector.intance);
			}
		}

		private ArrayList connectors = new ArrayList();
		
		/// <summary>
		/// Enregistre une nouvelle
		/// </summary>
		/// <param name="assemblyPath"></param>
		/// <param name="windowsDocType"></param>		
		public void Register(ExternalConnectorInfo connector)
		{
			// Vrifie les parametres
			if(connector == null)
			{
				throw new ArgumentNullException("connector");
			}

			connectors.Add(connector);
		}

		/// <summary>
		/// Renvoit la liste des connecteurs fabriques.
		/// </summary>
		/// <returns></returns>
		public System.Collections.IEnumerator GetWindowsDocumentFactory()
		{
			ArrayList windows = new ArrayList();

			// Core
			windows.Add(new CSVWindowsFactory());
			windows.Add(new AccessWindowsFactory());
			windows.Add(new OleDBWindowsFactory());

			// 
			for(int i = 0; i < connectors.Count; i++)
			{
				ExternalConnectorInfo eci = (ExternalConnectorInfo)connectors[i];
				IWindowsDocumentFactory factory = eci.CreateFactory();
				if(factory != null)
				{
					windows.Add(factory);
				}
			}
			return(windows.GetEnumerator());
		}		
	}
}
