/*=====================================================================
File: IDBDocument.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Data;
using System.Text;
using OpenCellar.Framework.Core;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// IDBDocument
	/// </summary>
    public abstract class IDBDocument : Document
    {
        /// <summary>
        /// Initialise une instance de classe IDBDocument.
        /// </summary>
        /// <param name="cellar"></param>
        /// <param name="commandText">Requete de selection.</param>
        /// <param name="connectionString">Chaine de connexion.</param>
        public IDBDocument(Cellar cellar, string connectionString, string commandText)
            : base(cellar)
        { 
            // Vrifie les parametres
            if((connectionString == null)
                | (connectionString == string.Empty))
            {
                throw new ArgumentNullException("connectionString");
            }

			if((commandText == null)
				| (commandText == string.Empty))
			{
				throw new ArgumentNullException("commandText");
			}

            this.commandText = commandText;
			this.connectionString = connectionString;
        }

		private string connectionString = null;

		/// <summary>
		/// Obtient la requete  executer.
		/// </summary>
		public string ConnectionString
		{
			get
			{
				return (this.connectionString);
			}
		}

        private string commandText = null;

        /// <summary>
        /// Obtient la requete  executer.
        /// </summary>
        public string CommandText
        {
            get
            {
                return (this.commandText);
            }
        }

        private string[] columnNames;

        /// <summary>
        /// Obtient la liste des entetes.
        /// </summary>
        /// <returns></returns>
        public override string[] GetColumnNames()
        {
            // Vrifie si le document est ouvert
            if (!base.IsOpen)
            {
                throw new Exception("Open::false");
            }

            if (base.ParseError)
            {
                throw new Exception("ParseError::true");
            }

            return (columnNames);
        }

        /// <summary>
        /// Ouvre le document spcifi.
        /// </summary>
        /// <returns></returns>
        public override bool Open()
        {
            // Vrifie que le document ne soit pas deja ouvert.
            if (base.IsOpen)
            {
                return(!base.ParseError);
            }

            if (base.ParseError)
            {
                throw new Exception("ParseError::true");
            }

            // Ouverture du document
            bool success = __parse();
            
            // Affectation des tas
            base.IsOpen = true;
            base.ParseError = !success;
            return (success);
        }

		protected abstract IDbConnection CreateConnection();

        /// <summary>
        /// Analyse le document.
        /// </summary>
        /// <returns></returns>
        private bool __parse()
        {
            bool success = false;

            IDbConnection connection = null;
			IDbCommand command = null;
			IDataReader reader = null;

            try
            {
				connection = CreateConnection();
				
				if(connection == null)
				{
					throw new ArgumentException("connection == null");
				}

				command = connection.CreateCommand();

				command.CommandText = this.CommandText;
				reader = command.ExecuteReader();

				// Entetes de colonne
                columnNames = new string[reader.FieldCount];
				for (int i = 0; i < columnNames.Length; i++)
				{
					columnNames[i] = reader.GetName(i);
				}
				
				// Lignes
                int lineNumber = 0;
                while (reader.Read())
                {
                    IRow row = new IDBRow(this, lineNumber, reader);
                    this.Rows.Add(row);
					lineNumber++;
                }

                success = true;
            }
            catch (Exception ex)
            {
                System.Diagnostics.Trace.WriteLine("__parseError() :: ");
                System.Diagnostics.Trace.WriteLine(ex.ToString());
            }
            finally
            {
				if(reader != null)
				{
					reader.Close();
					reader.Dispose();
				}
				
				if(command != null)
				{
					command.Dispose();
				}

                if (connection != null)
                {
                    connection.Close();
                }
            }

            return (success);
        }
    }
}
