/*=====================================================================
File: ProgressBar.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) MML Studio
=====================================================================*/
using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// ProgressBar.
	/// </summary>
	public class ProgressBar : Control
	{
		private StringFormat formatString = null;

		/// <summary>
		/// Initialise une instance de classe ProgressBar.
		/// </summary>
		public ProgressBar()
		{
			// Dfinition des styles
			base.SetStyle(ControlStyles.AllPaintingInWmPaint, true);
			base.SetStyle(ControlStyles.DoubleBuffer, true);
			base.SetStyle(ControlStyles.Opaque, true);
			base.SetStyle(ControlStyles.StandardDoubleClick, true);
			base.SetStyle(ControlStyles.UserPaint, true);
			// Mise  jour.
			base.UpdateStyles();

			formatString = new StringFormat();
			formatString.Alignment = StringAlignment.Center;
			formatString.LineAlignment = StringAlignment.Center;
		}

		private int m_value = 0;

		/// <summary>
		/// Obtient ou dfinit la valeur de la barre de progression.
		/// </summary>
		public int Value
		{
			get
			{
				return(m_value);
			}
			set
			{
				if(m_value != value)
				{
					m_value = value;
					this.Invalidate();
				}
			}
		}

		protected override void OnPaint(PaintEventArgs e)
		{
			if(DesignMode)
			{
				e.Graphics.Clear(this.BackColor);
				return;
			}

			Rectangle bounds = new Rectangle(0, 0, this.Width - 1, this.Height - 1);
			// Fond
			e.Graphics.Clear(this.BackColor);

			// Avancement
			if(Value > 0)
			{
				double dx = Math.Ceiling(((double)this.Value / 100.0f) * (double)this.Width);
				int percent = Convert.ToInt32(dx);
				using (LinearGradientBrush lgb = 
						   new LinearGradientBrush(bounds, Color.FromArgb(221, 236, 254), Color.FromArgb(59, 97, 156), 90f, false))
				{
					Rectangle wk = new Rectangle(0, 0, percent, this.Height);
					e.Graphics.FillRectangle(lgb, wk); 
				}
			}

			// Rectangle
			using(Pen p = new Pen(Color.Black))
			{
				e.Graphics.DrawRectangle(p, bounds);
			}

			using(SolidBrush sb = new SolidBrush(Color.Black))
			{
				e.Graphics.DrawString(this.Value.ToString() + "%", this.Font, sb, bounds, formatString);
			}
		}

		protected override void OnPaintBackground(PaintEventArgs pevent)
		{
			
		}
	}
}
