/*=====================================================================
File: Step1.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using OpenCellar.Import.Framework;
using OpenCellar.Framework.Core;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// Step1.
	/// </summary>
	public class Step1 : System.Windows.Forms.UserControl
	{
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.ComboBox datasourceCombo;
		private System.Windows.Forms.Button confButton;
		private System.Windows.Forms.Label label2;
		/// <summary> 
		/// Variable ncessaire au concepteur.
		/// </summary>
		private System.ComponentModel.Container components = null;

		/// <summary>
		/// Initialise une instance de classe Step1.
		/// </summary>
		/// <param name="cellar">Cave de destination.</param>
		public Step1(Cellar cellar)
		{
			// Cet appel est requis par le Concepteur de formulaires Windows.Forms.
			InitializeComponent();

			CreateDataSource();
			this.cellar = cellar;
			label2.Text = "Bienvenue dans l'assistant importation de donnes externes.\n\nConfigurer la source de donnes puis cliquez sur le bouton Suivant.";
		}

		private Cellar cellar = null;

		/// <summary>
		/// Obtient une rfrence vers la cave active.
		/// </summary>
		private Cellar Cellar
		{
			get
			{
				return(this.cellar);
			}
		}

		/// <summary>
		/// Se produit lorsque l'utilisateur a selectionn son document.
		/// </summary>
		public event EventHandler DocumentSelected;

		protected void OnDocumentSelected()
		{
			if(DocumentSelected != null)
			{
				DocumentSelected(this, EventArgs.Empty);
			}
		}

		private IDocument document = null;

		/// <summary>
		/// Obtient une rfrence vers le document cre.
		/// </summary>
		public IDocument Document
		{
			get
			{
				return(this.document);
			}
		}

		/// <summary>
		/// Charge la liste des connecteurs.
		/// </summary>
		private void CreateDataSource()
		{
			datasourceCombo.Items.Clear();
			datasourceCombo.Items.Add("<Slectionner un fournisseur>");
			IEnumerator windowsFactory = ExternalConnector.Instance.GetWindowsDocumentFactory();
			while(windowsFactory.MoveNext())
			{
				datasourceCombo.Items.Add(windowsFactory.Current);
			}
			datasourceCombo.SelectedIndex = 0;
		}

		/// <summary> 
		/// Nettoyage des ressources utilises.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Code gnr par le Concepteur de composants
		/// <summary> 
		/// Mthode requise pour la prise en charge du concepteur - ne modifiez pas 
		/// le contenu de cette mthode avec l'diteur de code.
		/// </summary>
		private void InitializeComponent()
		{
			this.label1 = new System.Windows.Forms.Label();
			this.datasourceCombo = new System.Windows.Forms.ComboBox();
			this.confButton = new System.Windows.Forms.Button();
			this.label2 = new System.Windows.Forms.Label();
			this.SuspendLayout();
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(16, 96);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(464, 23);
			this.label1.TabIndex = 0;
			this.label1.Text = "Selectionner le type de source de donnes";
			// 
			// datasourceCombo
			// 
			this.datasourceCombo.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.datasourceCombo.Location = new System.Drawing.Point(24, 128);
			this.datasourceCombo.Name = "datasourceCombo";
			this.datasourceCombo.Size = new System.Drawing.Size(272, 21);
			this.datasourceCombo.TabIndex = 1;
			// 
			// confButton
			// 
			this.confButton.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.confButton.Location = new System.Drawing.Point(304, 128);
			this.confButton.Name = "confButton";
			this.confButton.Size = new System.Drawing.Size(88, 23);
			this.confButton.TabIndex = 2;
			this.confButton.Text = "Configurer";
			this.confButton.Click += new System.EventHandler(this.confButton_Click);
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(16, 32);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(464, 48);
			this.label2.TabIndex = 3;
			this.label2.Text = "Bienvenue dans l\'assistant importation de donnes...";
			// 
			// Step1
			// 
			this.Controls.Add(this.label2);
			this.Controls.Add(this.confButton);
			this.Controls.Add(this.datasourceCombo);
			this.Controls.Add(this.label1);
			this.Name = "Step1";
			this.Size = new System.Drawing.Size(504, 264);
			this.ResumeLayout(false);

		}
		#endregion

		
		/// <summary>
		/// Affiche la fenetre de configuration.
		/// </summary>
		/// <param name="factory">Fabrique de document.</param>
		private void ShowUI(IWindowsDocumentFactory factory)
		{
			this.document = factory.CreateDocument(this.Cellar);

			if(this.document != null)
			{
				OnDocumentSelected();
			}
		}

		private void confButton_Click(object sender, System.EventArgs e)
		{
			if(datasourceCombo.SelectedIndex > 0)
			{
				ShowUI((IWindowsDocumentFactory)datasourceCombo.SelectedItem);
			}
		}
	}
}
