/*=====================================================================
File: Step2.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using OpenCellar.Import.Framework;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// Step2.
	/// </summary>
	public class Step2 : System.Windows.Forms.UserControl
	{
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.ComboBox targetColumn;
		private System.Windows.Forms.GroupBox groupBox2;
		private System.Windows.Forms.ListBox availableColumns;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label rowsCount;
		private System.Windows.Forms.Label dataSample;
		/// <summary> 
		/// Variable ncessaire au concepteur.
		/// </summary>
		private System.ComponentModel.Container components = null;

		/// <summary>
		/// Initialise une instance de classe Step2.
		/// </summary>
		/// <param name="document">Document source</param>
		public Step2(IDocument document)
		{
			// Cet appel est requis par le Concepteur de formulaires Windows.Forms.
			InitializeComponent();

			this.document = document;
			
			AutoMatch();

			this.availableColumns.SelectedIndexChanged+=new EventHandler(OnAvailableSelectionChanged);
			BindAvailableColumns();

			// Textes
			label1.Text = "Slectionnez les champs  importer puis parametrez les proprits de destination.";
			rowsCount.Text = "Nombre de lignes : " + this.Document.Rows.Count.ToString();
		}

		private IDocument document = null;

		/// <summary>
		/// Obtient une rfrence vers le document de travail.
		/// </summary>
		private IDocument Document
		{
			get
			{
				return(this.document);
			}
		}

		/// <summary>
		/// Charge les colonnes de la source de donnes.
		/// </summary>
		private void BindAvailableColumns()
		{
			int oldIndex = this.availableColumns.SelectedIndex;
			this.availableColumns.SelectedIndexChanged-=new EventHandler(OnAvailableSelectionChanged);
			this.availableColumns.BeginUpdate();
			this.availableColumns.Items.Clear();

			string[] columnNames = Document.GetColumnNames();

			for (int i = 0; i < columnNames.Length; i++)
			{
				string name = columnNames[i];
				
				if(IsMapped(i))
				{
					name += " (*)";
				}
				
				availableColumns.Items.Add(name);
			}

			this.availableColumns.EndUpdate();
			this.availableColumns.SelectedIndexChanged+=new EventHandler(OnAvailableSelectionChanged);

			// Selectionne la premiere colonne
			if((availableColumns.Items.Count > 0)
				&& (oldIndex == -1))
			{
				availableColumns.SelectedIndex = 0;
			} 
			else if(oldIndex > -1)
			{
				availableColumns.SelectedIndex = oldIndex;
			}			
		}

		
		/// <summary>
		/// Affiche la liste des colonnes restantes  placer.
		/// </summary>
		/// <param name="sourceIndex"></param>
		private void LoadAvailableColumns(int sourceIndex)
		{
			targetColumn.LostFocus-=new EventHandler(OnAddRemoveColumn);
			targetColumn.BeginUpdate();
			targetColumn.Items.Clear();
			targetColumn.Items.Add("Ne pas importer ce champ");

			for (int i = 0; i < Document.AvailableColumns.Count; i++)
			{
				IColumn column = Document.AvailableColumns[i];
				
				targetColumn.Items.Add(column);

				if(column.Index == sourceIndex)
				{
					targetColumn.SelectedIndex = (i + 1);
				}
			}

			if(targetColumn.SelectedIndex == -1)
			{
				targetColumn.SelectedIndex = 0;
			}

			targetColumn.EndUpdate();

			targetColumn.LostFocus+=new EventHandler(OnAddRemoveColumn);

			dataSample.Text = "Donnes de la colonne : \n";
			for (int i = 0; i < this.Document.Rows.Count; i++)
			{
				if(i > 4)
				{
					break;
				}

				IRow row = this.Document.Rows[i];

				if(row.CheckIndice(sourceIndex))
				{
					if(row[sourceIndex] == string.Empty)
					{
						dataSample.Text+="(vide)\n";
					}
					else
					{
						dataSample.Text+=this.Document.Rows[i][sourceIndex] + "\n";
					}
				}
			}
		}

		/// <summary> 
		/// Nettoyage des ressources utilises.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Code gnr par le Concepteur de composants
		/// <summary> 
		/// Mthode requise pour la prise en charge du concepteur - ne modifiez pas 
		/// le contenu de cette mthode avec l'diteur de code.
		/// </summary>
		private void InitializeComponent()
		{
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.rowsCount = new System.Windows.Forms.Label();
			this.targetColumn = new System.Windows.Forms.ComboBox();
			this.groupBox2 = new System.Windows.Forms.GroupBox();
			this.availableColumns = new System.Windows.Forms.ListBox();
			this.label1 = new System.Windows.Forms.Label();
			this.dataSample = new System.Windows.Forms.Label();
			this.groupBox1.SuspendLayout();
			this.groupBox2.SuspendLayout();
			this.SuspendLayout();
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.dataSample);
			this.groupBox1.Controls.Add(this.rowsCount);
			this.groupBox1.Controls.Add(this.targetColumn);
			this.groupBox1.Location = new System.Drawing.Point(240, 40);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(256, 208);
			this.groupBox1.TabIndex = 2;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "Proprits de mappage";
			// 
			// rowsCount
			// 
			this.rowsCount.Location = new System.Drawing.Point(16, 72);
			this.rowsCount.Name = "rowsCount";
			this.rowsCount.Size = new System.Drawing.Size(224, 23);
			this.rowsCount.TabIndex = 1;
			this.rowsCount.Text = "label2";
			// 
			// targetColumn
			// 
			this.targetColumn.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.targetColumn.Location = new System.Drawing.Point(16, 32);
			this.targetColumn.MaxDropDownItems = 14;
			this.targetColumn.Name = "targetColumn";
			this.targetColumn.Size = new System.Drawing.Size(232, 21);
			this.targetColumn.TabIndex = 0;
			// 
			// groupBox2
			// 
			this.groupBox2.Controls.Add(this.availableColumns);
			this.groupBox2.Location = new System.Drawing.Point(8, 40);
			this.groupBox2.Name = "groupBox2";
			this.groupBox2.Size = new System.Drawing.Size(224, 208);
			this.groupBox2.TabIndex = 3;
			this.groupBox2.TabStop = false;
			this.groupBox2.Text = "Champs source de donnes";
			// 
			// availableColumns
			// 
			this.availableColumns.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.availableColumns.Location = new System.Drawing.Point(16, 24);
			this.availableColumns.Name = "availableColumns";
			this.availableColumns.Size = new System.Drawing.Size(192, 171);
			this.availableColumns.TabIndex = 2;
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(16, 8);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(472, 23);
			this.label1.TabIndex = 4;
			this.label1.Text = "## Explications qui vont bien";
			// 
			// dataSample
			// 
			this.dataSample.Location = new System.Drawing.Point(16, 96);
			this.dataSample.Name = "dataSample";
			this.dataSample.Size = new System.Drawing.Size(224, 96);
			this.dataSample.TabIndex = 2;
			// 
			// Step2
			// 
			this.Controls.Add(this.label1);
			this.Controls.Add(this.groupBox2);
			this.Controls.Add(this.groupBox1);
			this.Name = "Step2";
			this.Size = new System.Drawing.Size(504, 264);
			this.groupBox1.ResumeLayout(false);
			this.groupBox2.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		private void OnAvailableSelectionChanged(object sender, EventArgs e)
		{
			LoadAvailableColumns(availableColumns.SelectedIndex);
		}

		/// <summary>
		/// Renvoit si la colonne est mappe
		/// </summary>
		/// <param name="index"></param>
		/// <returns></returns>
		private bool IsMapped(int index)
		{
			for (int i = 0; i < this.Document.Columns.Count; i++)
			{
				if(this.Document.Columns[i].Index == index)
				{
					return(true);
				}
			}	

			return(false);
		}

		private void AutoMatch()
		{
			bool ret = false;

			string[] columnNames = Document.GetColumnNames();

			for (int i = 0; i < Document.AvailableColumns.Count; i++)
			{
				IColumn column = Document.AvailableColumns[i];
				
				for (int j = 0; j < columnNames.Length; j++)
				{
					if(column.Name.ToLower() == columnNames[j].ToLower())
					{
						column.Index = j;
						this.Document.Columns.Add(column);
						ret = true;
						break;
					}
				}
			}

			if(ret)
			{
				MessageBox.Show("Au moins une colonne a t mapp par l'assistant.\n\nNote : les colonnes mappes apparaissent avec (*)");
			}
		}

		private void OnAddRemoveColumn(object sender, EventArgs e)
		{
			int sourceIndex = availableColumns.SelectedIndex;

			if(sourceIndex > -1)
			{
				if(targetColumn.SelectedIndex == 0) // Ne rien faire
				{
					// Suppression de la colonne
					for (int i = 0; i < this.Document.Columns.Count; i++)
					{
						if(this.Document.Columns[i].Index == sourceIndex)
						{
							this.Document.Columns.Remove(this.Document.Columns[i]);
							break;
						}
					}
				}
				else
				{
					// Ajout de la colonne
					IColumn column = (IColumn)targetColumn.SelectedItem;
					column.Index = sourceIndex;
					this.Document.Columns.Add(column);
				}

				// Met  jour les colonnes
				BindAvailableColumns();
			}
		}
	}
}
