/*=====================================================================
File: Wizard.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using OpenCellar.Import.Framework;
using OpenCellar.Framework.Core;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// Wizard.
	/// </summary>
	public class Wizard : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.Button nextStep;
		private System.Windows.Forms.Panel navPanel;
		private System.Windows.Forms.Panel contentPanel;
		private System.Windows.Forms.PictureBox picWizard;
		private System.Windows.Forms.Label lblName;

		/// <summary>
		/// Variable ncessaire au concepteur.
		/// </summary>
		private System.ComponentModel.Container components = null;

		/// <summary>
		/// Initialise une instance de classe BaseWizeard.
		/// </summary>
		/// <param name="cellar">Cave cible</param>
		public Wizard(Cellar cellar)
		{
			//
			// Requis pour la prise en charge du Concepteur Windows Forms
			//
			InitializeComponent();

			this.cellar = cellar;
			CreateControls();
			Step1();
		}

		/// <summary>
		/// Cre les controles du formulaire.
		/// </summary>
		private void CreateControls()
		{
			// Sparateurs
			Control topLine = new Control();
			topLine.BackColor = Color.Black;
			topLine.Location = new Point(0, this.navPanel.Bottom);
			topLine.Size = new Size(this.Width, 1);
			Controls.Add(topLine);
			topLine.BringToFront();

			Control bottomLine = new Control();
			bottomLine.BackColor = Color.Black;
			bottomLine.Location = new Point(0, this.cancelButton.Top - 12);
			bottomLine.Size = new Size(this.Width, 1);
			Controls.Add(bottomLine);
			bottomLine.BringToFront();
		}

		private Cellar cellar = null;

		/// <summary>
		/// Obtient une rfrence vers la cave active.
		/// </summary>
		public Cellar Cellar
		{
			get
			{
				return(this.cellar);
			}
		}

		private IDocument document = null;

		/// <summary>
		/// Obtient le document de travail.
		/// </summary>
		private IDocument Document
		{
			get
			{
				return(this.document);
			}
		}

		/// <summary>
		/// Etape 1.
		/// </summary>
		private void Step1()
		{
			currentStep = 1;

			Step1 step1 = new Step1(this.Cellar);
			step1.Location = new Point(0, 0);
			step1.Size = contentPanel.Size;
			step1.DocumentSelected+=new EventHandler(OnDocumentSelected);
			contentPanel.Controls.Add(step1);
			nextStep.Enabled = false;
		}

		/// <summary>
		/// Etape 2.
		/// </summary>
		private void Step2()
		{
			currentStep = 2;
			UIUtility.HideChildControls(contentPanel);
			nextStep.Enabled = true;

			// Affichage
			Step2 step2 = new Step2(this.document);
			step2.Location = new Point(0, 0);
			step2.Size = contentPanel.Size;
			contentPanel.Controls.Add(step2);
		}

		/// <summary>
		/// Etape 3.
		/// </summary>
		private void Step3()
		{
			currentStep = 3;
			UIUtility.HideChildControls(contentPanel);

			// Affichage
			Step3 step3 = new Step3(this.document);
			step3.Location = new Point(0, 0);
			step3.Size = contentPanel.Size;
			contentPanel.Controls.Add(step3);
			nextStep.Enabled = false;
			cancelButton.Visible = false;
			UIUtility.DoEvents();

			// events
			this.Document.BeginProcess+=new EventHandler(Document_BeginProcess);
			this.Document.EndProcess+=new EventHandler(Document_EndProcess);
			this.Document.Process();
		}

		/// <summary>
		/// Nettoyage des ressources utilises.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Code gnr par le Concepteur Windows Form
		/// <summary>
		/// Mthode requise pour la prise en charge du concepteur - ne modifiez pas
		/// le contenu de cette mthode avec l'diteur de code.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(Wizard));
			this.contentPanel = new System.Windows.Forms.Panel();
			this.cancelButton = new System.Windows.Forms.Button();
			this.nextStep = new System.Windows.Forms.Button();
			this.navPanel = new System.Windows.Forms.Panel();
			this.picWizard = new System.Windows.Forms.PictureBox();
			this.lblName = new System.Windows.Forms.Label();
			this.navPanel.SuspendLayout();
			this.SuspendLayout();
			// 
			// contentPanel
			// 
			this.contentPanel.Location = new System.Drawing.Point(0, 64);
			this.contentPanel.Name = "contentPanel";
			this.contentPanel.Size = new System.Drawing.Size(504, 264);
			this.contentPanel.TabIndex = 0;
			// 
			// cancelButton
			// 
			this.cancelButton.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.cancelButton.Location = new System.Drawing.Point(8, 344);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.Size = new System.Drawing.Size(96, 23);
			this.cancelButton.TabIndex = 1;
			this.cancelButton.Text = "Annuler";
			this.cancelButton.Click += new System.EventHandler(this.cancelButton_Click);
			// 
			// nextStep
			// 
			this.nextStep.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.nextStep.Location = new System.Drawing.Point(400, 344);
			this.nextStep.Name = "nextStep";
			this.nextStep.Size = new System.Drawing.Size(96, 23);
			this.nextStep.TabIndex = 2;
			this.nextStep.Text = "Suivant";
			this.nextStep.Click += new System.EventHandler(this.nextStep_Click);
			// 
			// navPanel
			// 
			this.navPanel.BackColor = System.Drawing.Color.White;
			this.navPanel.Controls.Add(this.picWizard);
			this.navPanel.Controls.Add(this.lblName);
			this.navPanel.Location = new System.Drawing.Point(0, 0);
			this.navPanel.Name = "navPanel";
			this.navPanel.Size = new System.Drawing.Size(504, 64);
			this.navPanel.TabIndex = 3;
			// 
			// picWizard
			// 
			this.picWizard.Image = ((System.Drawing.Image)(resources.GetObject("picWizard.Image")));
			this.picWizard.Location = new System.Drawing.Point(424, 6);
			this.picWizard.Name = "picWizard";
			this.picWizard.Size = new System.Drawing.Size(48, 48);
			this.picWizard.TabIndex = 38;
			this.picWizard.TabStop = false;
			// 
			// lblName
			// 
			this.lblName.Font = new System.Drawing.Font("Tahoma", 12F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblName.Location = new System.Drawing.Point(8, 0);
			this.lblName.Name = "lblName";
			this.lblName.Size = new System.Drawing.Size(392, 64);
			this.lblName.TabIndex = 37;
			this.lblName.Text = "Assistant importation de donnes externes";
			this.lblName.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// Wizard
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 14);
			this.BackColor = System.Drawing.SystemColors.Control;
			this.ClientSize = new System.Drawing.Size(504, 374);
			this.Controls.Add(this.navPanel);
			this.Controls.Add(this.nextStep);
			this.Controls.Add(this.cancelButton);
			this.Controls.Add(this.contentPanel);
			this.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Name = "Wizard";
			this.ShowInTaskbar = false;
			this.SizeGripStyle = System.Windows.Forms.SizeGripStyle.Hide;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "Assistant utilisateur";
			this.navPanel.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		int currentStep = 0;

		private void OnDocumentSelected(object sender, EventArgs e)
		{
			this.document = ((Step1)sender).Document;
			NextStep();
		}

		private void cancelButton_Click(object sender, System.EventArgs e)
		{
			if(MessageBox.Show("Etes-vous sur de vouloir quitter l'assistant ?", 
				"Open Cellar", 
				MessageBoxButtons.YesNo,
				MessageBoxIcon.Question) == DialogResult.Yes)
			{
				this.DialogResult = DialogResult.Cancel;
			}
		}

		private void nextStep_Click(object sender, System.EventArgs e)
		{
			NextStep();
		}

		/// <summary>
		/// Affiche l'tape suivante.
		/// </summary>
		private void NextStep()
		{
			if((currentStep == 1)
				&& (this.document != null))
			{
				UIUtility.SetWaitCursor(true, this);

				bool success = false;
			
				try
				{
					success = document.Open();
				}
				catch(Exception ex)
				{
					MessageBox.Show("Une erreur est survenue.\nVrifier les paramtres de la source de donnes.\n\nPile : \n" + ex.ToString(),
						"Open Cellar",
						MessageBoxButtons.OK,
						MessageBoxIcon.Error);
					success = false;
				}

				UIUtility.SetWaitCursor(false, this);

				if(success)
				{
					this.Step2();
				}
			}
			else if(currentStep == 2)
			{
				if(this.document.Columns.Count > 0)
				{
					Step3();
				}
				else
				{
					MessageBox.Show("Aucune proprit de mappage n'est configure.",
						"Open Cellar",
						MessageBoxButtons.OK,
						MessageBoxIcon.Warning);
				}
			}
			else if (currentStep == 3)
			{
				this.DialogResult = DialogResult.OK;
			}
		}

		private void Document_BeginProcess(object sender, EventArgs e)
		{
			UIUtility.SetWaitCursor(true, FindForm());
		}

		private void Document_EndProcess(object sender, EventArgs e)
		{
			UIUtility.SetWaitCursor(false, FindForm());
			nextStep.Enabled = true;
			nextStep.Text = "Terminer";
			MessageBox.Show("L'assistant importation de donnes externes a termin !\n\n" + this.Document.Rows.Count.ToString() + " lignes traites.",
				"Open Cellar",
				MessageBoxButtons.OK,
				MessageBoxIcon.Information);
		}
	}
}
