/*=====================================================================
File: Column.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Text;

namespace OpenCellar.Import.Framework
{
	/// <summary>
	/// Column
	/// </summary>
    public abstract class Column : IColumn
    {
        /// <summary>
        /// Intialise une instance de classe BaseColumn.
        /// </summary>
        /// <param name="name">Nom affiche de la colonne.</param>
        /// <param name="priority"></param>
        protected Column(string name, int priority)
        {
            // Vrifie les arguments
            if (priority < 0)
            {
                throw new ArgumentOutOfRangeException("priority");
            }

            if ((name == null)
                | (name == string.Empty))
            {
                throw new ArgumentNullException("name");
            }

            this.priority = priority;
            this.name = name;
        }

        /// <summary>
        /// Intialise une instance de classe BaseColumn.
        /// </summary>
        /// <param name="name">Nom affiche de la colonne.</param>
        protected Column(string name)
            : this(name, 1000)
        { 
            
        }

        /// <summary>
        /// Procde au mapping donne brute -> objet vin.
        /// </summary>
        /// <param name="wine">Vin cible.</param>
        /// <param name="row">Ligne d'importation.</param>
        /// <returns>Succs de l'opration.</returns>
        public virtual bool Process(OpenCellar.Framework.Core.Wine wine, IRow row)
        {
            return (false);
        }

        private string name = null;

        /// <summary>
        /// Obtient le nom affiche de la colonne.
        /// </summary>
        public virtual string Name
        {
            get 
            {
                return(this.name);
            }
        }

        private int priority = 0;

        /// <summary>
        /// Obtient la priorit de la colonne.
        /// </summary>
        public virtual int Priority
        {
            get 
            {
                return (this.priority);
            }
        }

        private int index = -1;

        /// <summary>
        /// Obtient ou dfinit l'index de la colonne source.
        /// </summary>
        public int Index
        {
            get
            {
                return (this.index);
            }
            set
            {
                this.index = value;
            }
        }

        // <summary>
        /// Cre une copie de la colonne.
        /// </summary>
        /// <returns></returns>
        public abstract IColumn Clone();

		public override string ToString()
		{
			return(Name);
		}

    }
}
