/*=====================================================================
File: ColumnCollection.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Collections;
using System.Text;

namespace OpenCellar.Import.Framework
{
    public class ColumnCollection : IColumnCollection
    {
        /// <summary>
        /// Constructeur protg de la classe ColumnCollection.
        /// </summary>
        /// <param name="readOnly"></param>
        public ColumnCollection(bool readOnly)
        {
            this.readOnly = readOnly;
        }

        private bool readOnly = false;

        /// <summary>
        /// Obtient si la liste est en lecture seule.
        /// </summary>
        public bool ReadOnly
        {
            get
            {
                return (this.readOnly);
            }
        }

        private ArrayList list = new ArrayList();

        /// <summary>
        /// Obtient le nombre de colonne contenu dans la liste.
        /// </summary>
        public int Count
        {
            get
            {
                return (this.list.Count);
            }
        }

        private void AssertReadOnly()
        {
            if (this.readOnly)
            {
                throw new Exception("La liste est en lecture seule.");
            }
        }

        /// <summary>
        /// Ajoute une colonne en fin de liste.
        /// </summary>
        /// <param name="column"></param>
        public void Add(IColumn column)
        {
            AssertReadOnly();

            if (column == null)
            {
                throw new ArgumentException("column");
            }

			// Supprime les colonnes ayant le mme mapping.
			int index = column.Index;

			if(index != -1)
			{
				for (int i = 0; i < this.Count; i++)
				{
					if(this[i].Index == index)
					{
						this.list.RemoveAt(i);
						break;
					}
				}
		
			}

            this.list.Add(column);
            OnListChanged();
        }

        private bool notifyEvent = true;

        /// <summary>
        /// Obtient ou dfinit si les evenements sont envoys.
        /// </summary>
        internal protected bool NotifyEvent
        {
            get
            {
                return (notifyEvent);
            }
            set
            {
                this.notifyEvent = value;
            }
        }

        /// <summary>
        /// Ajoute une colonne  la liste sans verification de lecture seule.
        /// </summary>
        /// <param name="column"></param>
        internal protected void __Add(IColumn column)
        {
            if (column == null)
            {
                throw new ArgumentException("column");
            }

            this.list.Add(column);
        }

        /// <summary>
        /// Supprime la colonne sans verification de lecture seule.
        /// </summary>
        /// <param name="column"></param>
        internal protected void __Remove(IColumn column)
        {
            if (column == null)
            {
                throw new ArgumentException("column");
            }

            this.list.Remove(column);
        }

        /// <summary>
        /// Fusionne les 2 listes.
        /// </summary>
        /// <param name="columns"></param>
        internal void Merge(ColumnCollection columns)
        {
            if (columns == null)
            {
                throw new ArgumentNullException("columns");
            }

            // 
            for (int i = 0; i < columns.Count; i++)
            {
                IColumn column = columns[i];
                if (this.Contains(column))
                {
                    columns.__Remove(column);
                }
            }
        }

        /// <summary>
        /// Renvoit si la colonne est prsente dans la liste.
        /// </summary>
        /// <param name="column"></param>
        /// <returns></returns>
        public bool Contains(IColumn column)
        {
            if (column == null)
            {
                throw new ArgumentNullException("column");
            }

            return (this.list.Contains(column));
        }

        /// <summary>
        /// Supprime la colonne spcifie.
        /// </summary>
        /// <param name="column"></param>
        public void Remove(IColumn column)
        {
            AssertReadOnly();

            if (column == null)
            {
                throw new ArgumentException("column");
            }

            this.list.Remove(column);
            OnListChanged();
        }

        /// <summary>
        /// Obtient la colonne spcifie en index.
        /// </summary>
        /// <param name="index">Index de la colonne.</param>
        /// <returns>IColumn correspondante</returns>
        public IColumn this[int index]
        {
            get
            {
                if ((index > -1)
                    && (index < this.list.Count))
                {
                    return ((IColumn)this.list[index]);
                }

                throw new ArgumentOutOfRangeException("index");
            }
        }

        /// <summary>
        /// Se produit lorsque la liste subit un changement.
        /// </summary>
        public event EventHandler ListChanged;

        /// <summary>
        /// Dclenche l'vnement ListChanged.
        /// </summary>
        protected void OnListChanged()
        {
            if ((NotifyEvent)
                && (ListChanged != null))
            {
                ListChanged(this, EventArgs.Empty);
            }
        }

        /// <summary>
        /// Tri les lments de la liste.
        /// </summary>
        public void Sort()
        {
            this.list.Sort(new ColumnComparer());
        }
    }
}
