/*=====================================================================
File: IDocument.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using OpenCellar.Framework.Core;

namespace OpenCellar.Import.Framework
{
    public interface IDocument
    {
        /// <summary>
        /// Obtient une rfrence vers la cave de destination.
        /// </summary>
        Cellar Cellar { get;}

        /// <summary>
        /// Obtient la liste des colonnes.
        /// </summary>
        /// <returns>Tableau de chaine contenant les colonnes.</returns>
        string[] GetColumnNames();

        /// <summary>
        /// Obtient la liste des lignes du document.
        /// </summary>
        IRowCollection Rows { get;}

        /// <summary>
        /// Obtient la liste des colonnes du document.
        /// </summary>
        IColumnCollection Columns { get;}

        /// <summary>
        /// Obtient la liste des colonnes disponibles.
        /// </summary>
        IColumnCollection AvailableColumns { get;}

        /// <summary>
        /// Procde  l'importation des donnes.
        /// </summary>
        /// <returns>Succs de l'opration.</returns>
        void Process();

        /// <summary>
        /// Ouvre le document.
        /// </summary>
        bool Open();

        /// <summary>
        /// Se produit lorsque l'tat d'avancement est modifi.
        /// </summary>
        event EventHandler ProgressChanged;

        /// <summary>
        /// Se produit lors du dmarrage de l'importation.
        /// </summary>
        event EventHandler BeginProcess;

        /// <summary>
        /// Se produit lorsque le processus d'importation est termine.
        /// </summary>
        event EventHandler EndProcess;
    }
}
