/*=====================================================================
File: OCUtility.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using OpenCellar.Framework.Core;

namespace OpenCellar.Import.Framework
{
    public class OCUtility
    {
        /// <summary>
        /// Tente de convertir la chaine pass en parametre en nombre flottant.
        /// </summary>
        /// <param name="source"></param>
        /// <param name="result">Rsultat de l'opration</param>
        /// <returns></returns>
        public static float TryParseFloat(string source, out bool result)
        {
            if((source == null)
                | (source == string.Empty))
            {
                result = false;
                return (0);
            }

            float ret = 0;

            try
            {
                source = source.Replace(" ", "");
                source = source.Replace(",", ".");
                ret = float.Parse(source, System.Globalization.CultureInfo.InvariantCulture);
                result = true;
            }
            catch
            {
                result = false;
            }

            return (ret);
        }

        /// <summary>
        /// Tente de convertir la chaine pass en parametre en octet.
        /// </summary>
        /// <param name="source"></param>
        /// <param name="result">Rsultat de l'opration</param>
        /// <returns></returns>
        public static byte TryParseByte(string source, out bool result)
        {
            if ((source == null)
                | (source == string.Empty))
            {
                result = false;
                return (0);
            }

            byte ret = 0;

            try
            {
                ret = byte.Parse(source, System.Globalization.CultureInfo.InvariantCulture);
                result = true;
            }
            catch
            {
                result = false;
            }

            return (ret);
        }

        /// <summary>
        /// Tente de convertir la chaine pass en parametre en entier.
        /// </summary>
        /// <param name="source"></param>
        /// <param name="result">Rsultat de l'opration</param>
        /// <returns></returns>
        public static int TryParseInt(string source, out bool result)
        {
            if ((source == null)
                | (source == string.Empty))
            {
                result = false;
                return (0);
            }

            int ret = 0;

            try
            {
                ret = int.Parse(source, System.Globalization.CultureInfo.InvariantCulture);
                result = true;
            }
            catch
            {
                result = false;
            }

            return (ret);
        }

        /// <summary>
        /// Tente de convertir la chaine pass en parametre en entier non sign.
        /// </summary>
        /// <param name="source"></param>
        /// <param name="result">Rsultat de l'opration</param>
        /// <returns></returns>
        public static ushort TryParseUShort(string source, out bool result)
        {
            if ((source == null)
                | (source == string.Empty))
            {
                result = false;
                return (0);
            }

            ushort ret = 0;

            try
            {
                ret = ushort.Parse(source, System.Globalization.CultureInfo.InvariantCulture);
                result = true;
            }
            catch
            {
                result = false;
            }

            return (ret);
        }


        /// <summary>
        /// Tente de convertir la chaine pass en parametre en entier non sign.
        /// </summary>
        /// <param name="source"></param>
        /// <param name="result">Rsultat de l'opration</param>
        /// <returns></returns>
        public static DateTime TryParseDateTime(string source, out bool result)
        {
            if ((source == null)
                | (source == string.Empty))
            {
                result = false;
                return (DateTime.MinValue);
            }

            DateTime ret = DateTime.MinValue;

            try
            {
                ret = DateTime.Parse(source); // Culture en cours
                result = true;
            }
            catch
            {
                result = false;
            }

            return (ret);
        }

		/// <summary>
		/// Cre l'lment du type spcifi.
		/// </summary>
		/// <param name="type"></param>
		/// <param name="searchName"></param>
		/// <returns></returns>
		public static BaseItem CreateBaseItem(Cellar cellar,
			ObjectType type, 
			string searchName)
		{

			// Vrifie le parametre
			if((searchName == null)
				| (searchName == string.Empty))
			{
				return(null);
			}

			ObjectCollection oc = cellar.GetCollection((ushort)type);
			for (int i = 0; i < oc.Count; i++)
			{
				if(((BaseItem)oc[i]).Name.Trim().ToLower() == searchName.ToLower())
				{
					return((BaseItem)oc[i]);
				}
			}

			// Element non trouv --> cration
			BaseItem item = (BaseItem)cellar.CreateItem(type);
			item.Name = searchName;
			item.Save();
			return(item);
		}


		/// <summary>
		/// Cre l'lment du type spcifi.
		/// </summary>
		/// <param name="type"></param>
		/// <param name="searchName"></param>
		/// <returns></returns>
		public static Contact CreateContact(Cellar cellar, 
			ObjectType type, 
			string searchName)
		{

			// Vrifie le parametre
			if((searchName == null)
				| (searchName == string.Empty))
			{
				return(null);
			}

			ObjectCollection oc = cellar.GetCollection((ushort)type);
			for (int i = 0; i < oc.Count; i++)
			{
				if(((Contact)oc[i]).Name.Trim().ToLower() == searchName.ToLower())
				{
					return((Contact)oc[i]);
				}
			}

			// Element non trouv --> cration
			Contact item = (Contact)cellar.CreateItem(type);
			item.Name = searchName;
			item.Save();
			return(item);
		}
    }
}
