/*=====================================================================
File: Row.cs

Summary: 

Date : Septembre 2007

Origin: Open Cellar ! Project

Revision:

Aut: Matthieu DUCROCQ

---------------------------------------------------------------------
Copyright (C) Matthieu DUCROCQ
=====================================================================*/
using System;
using System.Collections.Specialized;

namespace OpenCellar.Import.Framework
{
    public abstract class Row : IRow
    {
        /// <summary>
        /// Constructeur protge de la classe BaseRow.
        /// </summary>
        /// <param name="rowIndex">Index de la ligne.</param>
        protected Row(IDocument parent, 
            int rowIndex)
        {
            if (rowIndex < 0)
            {
                throw new ArgumentException("rowIndex < 0");
            }

            if (parent == null)
            {
                throw new ArgumentNullException("parent");
            }

            this.parent = parent;
            this.rowIndex = rowIndex;
        }

        private int rowIndex = -1;

        /// <summary>
        /// Obtient l'index de la ligne.
        /// </summary>
        public int RowIndex
        {
            get
            {
                return (this.rowIndex);
            }
        }

        private StringCollection values = new StringCollection();

        /// <summary>
        /// Vrifie la validit de l'indice.
        /// </summary>
        /// <param name="index"></param>
        /// <returns></returns>
        public bool CheckIndice(int index)
        {
            return (((index > -1)
                && (index < values.Count)));
        }

        /// <summary>
        /// Obtient la chaine  la position spcifie.
        /// </summary>
        /// <param name="index">Index de la chaine a recuperer.</param>
        /// <returns></returns>
        public string this[int index]
        {
            get
            {
                if ((index > -1)
                    && (index < values.Count))
                {
                    return (values[index]);
                }

                throw new ArgumentOutOfRangeException("index");
            }
        }

        protected void Add(string value)
        {
            if (value == null)
            {
                throw new ArgumentNullException("value");
            }

            this.values.Add(value.Trim());
        }

        private IDocument parent = null;

        /// <summary>
        /// Obtient une rfrence vers le document parent.
        /// </summary>
        public IDocument Parent
        {
            get
            {
                return (this.parent);
            }
        }

        /// <summary>
        /// Renvoit le tableau de chaine.
        /// </summary>
        public string[] ToStringArray()
        {
            string[] stringArray = new string[this.values.Count];
           
            for (int i = 0; i < this.values.Count; i++)
            {
                stringArray[i] = this.values[i];
            }

            return (stringArray);
        }
    }
}
